This directory contains preliminary code for rendering images using the Neocortix Scalable Compute and the open source Blender tool.
In the current beta version, it is incomplete and not supported.
For more information, see https://www.neocortix.com/tutorials-render-blender-many
